==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_fields/FLEETVEHICLETICKETID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour FLEETVEHICLETICKETID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="FLEETVEHICLETICKETID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FLEETVEHICLETICKETCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FLEETVEHICLETICKETID_Type", propOrder = {
    "fleetvehicleticketcode",
    "organizationid"
})
public class FLEETVEHICLETICKETID_Type {

    @XmlElement(name = "FLEETVEHICLETICKETCODE", required = true)
    protected String fleetvehicleticketcode;
    @XmlElement(name = "ORGANIZATIONID")
    protected ORGANIZATIONID_Type organizationid;

    /**
     * Obtient la valeur de la propriété fleetvehicleticketcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFLEETVEHICLETICKETCODE() {
        return fleetvehicleticketcode;
    }

    /**
     * Définit la valeur de la propriété fleetvehicleticketcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFLEETVEHICLETICKETCODE(String value) {
        this.fleetvehicleticketcode = value;
    }

    /**
     * Obtient la valeur de la propriété organizationid.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Définit la valeur de la propriété organizationid.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/FLEETVEHICLETICKETID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for FLEETVEHICLETICKETID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="FLEETVEHICLETICKETID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FLEETVEHICLETICKETCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "FLEETVEHICLETICKETID_Type", propOrder = {
    "fleetvehicleticketcode",
    "organizationid"
})
public class FLEETVEHICLETICKETID_Type {

    @XmlElement(name = "FLEETVEHICLETICKETCODE", required = true)
    protected String fleetvehicleticketcode;
    @XmlElement(name = "ORGANIZATIONID")
    protected ORGANIZATIONID_Type organizationid;

    /**
     * Gets the value of the fleetvehicleticketcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFLEETVEHICLETICKETCODE() {
        return fleetvehicleticketcode;
    }

    /**
     * Sets the value of the fleetvehicleticketcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFLEETVEHICLETICKETCODE(String value) {
        this.fleetvehicleticketcode = value;
    }

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

}
